@@ -17,12 +17,8 @@ cmd = []
 
 # Python.h.
 include = '%s/include/python%s/' % (path, target)
-if target == '3.2':
-    include = '%s/include/python3.2m/' % path
-elif target == '3.3':
-    include = '%s/include/python3.3m/' % path
-elif target == '3.4':
-    include = '%s/include/python3.4m/' % path
+if target in ['3.2', '3.3', '3.4', '3.5']:
+    include = '%s/include/python%sm/' % (path, target)
 
 # Python 3.2 installed in the home directory.
 cmd.append("gcc -o target_functions/c_chi2.os -c -I%s -fPIC target_functions/c_chi2.c" % include)
