@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2012-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2012-2015 Edward d'Auvergne                                   #
 # Copyright (C) 2014 Troels E. Linnet                                         #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
@@ -96,11 +96,8 @@ def build_uf_menus(parent=None, menubar=None):
                 # Get the user function class data object.
                 class_data = uf_info.get_class(class_name)
 
-                # Create a unique ID.
-                class_id = wx.NewId()
-
                 # Create the menu entry.
-                class_item = build_menu_item(menu, id=class_id, text=class_data.menu_text, icon=fetch_icon(class_data.gui_icon, size='16x16'))
+                class_item = build_menu_item(menu, id=-1, text=class_data.menu_text, icon=fetch_icon(class_data.gui_icon, size='16x16'))
 
                 # Initialise the sub menu.
                 sub_menu = wx.Menu()
@@ -198,7 +195,7 @@ class Uf_object(object):
             self._sync = wx_wizard_sync
 
         # Create a new wizard if needed (checking that the parent of an old wizard is not the same).
-        if self.wizard == None or (wx_parent != None and wx_parent != self.wizard.GetParent()) or self.wizard._pages[0] == None:
+        if self.wizard == None or (wx_parent != None and wx_parent != self.wizard.GetParent()) or len(self.wizard._pages) == 0:
             status = self.create_wizard(wx_parent)
             if not status:
                 return False
@@ -252,6 +249,29 @@ class Uf_object(object):
         self._uf_id = wx.NewId()
 
 
+    def Destroy(self):
+        """Cleanly destroy the user function GUI elements."""
+
+        # First flush all events.
+        wx.Yield()
+
+        # Destroy the user function page.
+        if hasattr(self, 'page'):
+            # Loop over the user function arguments.
+            for key in self.page.uf_args:
+                # Destroy any selection windows.
+                if hasattr(self.page.uf_args[key], 'sel_win'):
+                    self.page.uf_args[key].sel_win.Destroy()
+
+            # Delete the page object.
+            del self.page
+
+        # Destroy the wizard, if it exists.
+        if self.wizard != None:
+            self.wizard.Destroy()
+            self.wizard = None
+
+
     def create_page(self, wizard=None, sync=None, execute=True):
         """Create the user function wizard page GUI object.
 
@@ -288,7 +308,7 @@ class Uf_object(object):
             parent = app.gui
 
         # Create the wizard dialog.
-        self.wizard = Wiz_window(parent=parent, size_x=self._size[0], size_y=self._size[1], title=self._title)
+        self.wizard = Wiz_window(parent=parent, size_x=self._size[0], size_y=self._size[1], title="The %s user function"%self._name)
 
         # Create the page.
         self.page = self.create_page(self.wizard, sync=self._sync)
@@ -447,7 +467,7 @@ class Uf_page(Wiz_page):
         """
 
         # The key is not set, so assume this is a hidden argument.
-        if key not in self.uf_args.keys():
+        if key not in self.uf_args:
             return None
 
         # Call the argument element's method.
@@ -709,6 +729,9 @@ class Uf_page(Wiz_page):
                         for j in range(len(element)):
                             text += "    - %s\n" % element[j]
 
+                        # Remove the last newline character.
+                        text = text[:-1]
+
                     # Format the item lists.
                     elif type == 'item list':
                         # Loop over the list elements.
@@ -719,11 +742,17 @@ class Uf_page(Wiz_page):
                             else:
                                 text += "    %s:  %s\n" % (element[j][0], element[j][1])
 
+                        # Remove the last newline character.
+                        text = text[:-1]
+
                     # Format prompt items.
                     elif type == 'prompt':
                         for j in range(len(element)):
                             text += "%s\n" % element[j]
 
+                        # Remove the last newline character.
+                        text = text[:-1]
+
                     # The text object.
                     text_obj = wx.StaticText(panel, -1, text, style=wx.TE_MULTILINE)
 
@@ -996,6 +1025,6 @@ class Uf_storage(dict):
         """
 
         # Loop over the elements, returning the name when a match occurs.
-        for name in self.keys():
+        for name in self:
             if self[name]._uf_id == id:
                 return name
