@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2013-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2013-2015 Edward d'Auvergne                                   #
 # Copyright (C) 2014 Troels E. Linnet                                         #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
@@ -48,9 +48,11 @@ __all__ = [
     'order',
     'periodic_table',
     'physical_constants',
+    'plotting',
     'regex',
     'selection',
     'sequence',
+    'sequence_alignment',
     'software',
     'spectral_densities',
     'spectrum',
