@@ -27,16 +27,21 @@ from math import pi
 from numpy import array, float64, zeros
 
 # relax module imports.
-from specific_analyses.frame_order.data import pivot_fixed, translation_fixed
+from lib.errors import RelaxError
+from lib.frame_order.variables import MODEL_DOUBLE_ROTOR, MODEL_FREE_ROTOR, MODEL_ISO_CONE, MODEL_ISO_CONE_FREE_ROTOR, MODEL_ISO_CONE_TORSIONLESS, MODEL_LIST_FREE_ROTORS, MODEL_LIST_ISO_CONE, MODEL_LIST_PSEUDO_ELLIPSE, MODEL_PSEUDO_ELLIPSE, MODEL_ROTOR
+from lib.list import unique_elements
+from specific_analyses.frame_order.data import pivot_fixed
 
 
-def assemble_param_vector(sim_index=None):
+def assemble_param_vector(sim_index=None, unset_fail=False):
     """Assemble and return the parameter vector.
 
-    @return:            The parameter vector.
-    @rtype:             numpy rank-1 array
-    @keyword sim_index: The Monte Carlo simulation index.
-    @type sim_index:    int
+    @keyword sim_index:     The Monte Carlo simulation index.
+    @type sim_index:        int
+    @keyword unset_fail:    A flag which if True will cause a RelaxError to be raised if the parameter is not set yet.
+    @type unset_fail:       bool
+    @return:                The parameter vector.
+    @rtype:                 numpy rank-1 array
     """
 
     # Initialise.
@@ -49,8 +54,19 @@ def assemble_param_vector(sim_index=None):
 
     # Loop over all model parameters.
     for param_name in cdp.params:
+        # Add the extension.
+        param_name += ext
+
+        # The parameter does not exist yet.
+        if not hasattr(cdp, param_name):
+            if unset_fail:
+                raise RelaxError("The parameter '%s' has not been set." % param_name)
+            else:
+                param_vect.append(None)
+                continue
+
         # Get the object.
-        obj = getattr(cdp, param_name+ext)
+        obj = getattr(cdp, param_name)
 
         # Add it to the parameter vector.
         if sim_index == None:
@@ -75,7 +91,16 @@ def linear_constraints(scaling_matrix=None):
         -0.125 <= S <= 1,
         0 <= sigma_max <= pi,
 
-    The pivot point parameter, domain position parameters, and eigenframe parameters are unconstrained.
+    The pivot point and average domain position parameter constraints are::
+
+        -999 <= pivot_x <= 999
+        -999 <= pivot_y <= 999
+        -999 <= pivot_z <= 999
+        -500 <= ave_pos_x <= 500
+        -500 <= ave_pos_y <= 500
+        -500 <= ave_pos_y <= 500
+    
+    These are necessary to allow for valid PDB representations to be created.  The eigenframe parameters are unconstrained.
 
 
     Matrix notation
@@ -83,27 +108,49 @@ def linear_constraints(scaling_matrix=None):
 
     In the notation A.x >= b, where A is an matrix of coefficients, x is an array of parameter values, and b is a vector of scalars, these inequality constraints are::
 
-        | 1  0  0  0  0 |                        |   0    |
-        |               |                        |        |
-        |-1  0  0  0  0 |                        |  -pi   |
-        |               |                        |        |
-        | 0  1  0  0  0 |                        |   0    |
-        |               |                        |        |
-        | 0 -1  0  0  0 |     |   theta   |      |  -pi   |
-        |               |     |           |      |        |
-        | 0 -1  1  0  0 |     |  theta_x  |      |   0    |
-        |               |     |           |      |        |
-        | 0  0  1  0  0 |  .  |  theta_y  |  >=  |   0    |
-        |               |     |           |      |        |
-        | 0  0 -1  0  0 |     |    S      |      |  -pi   |
-        |               |     |           |      |        |
-        | 0  0  0  1  0 |     | sigma_max |      | -0.125 |
-        |               |                        |        |
-        | 0  0  0 -1  0 |                        |  -1    |
-        |               |                        |        |
-        | 0  0  0  0  1 |                        |   0    |
-        |               |                        |        |
-        | 0  0  0  0 -1 |                        |  -pi   |
+        | 1  0  0  0 |                        |   0    |
+        |            |                        |        |
+        |-1  0  0  0 |                        |  -pi   |
+        |            |                        |        |
+        | 0  1  0  0 |                        |   0    |
+        |            |     |   theta   |      |        |
+        | 0 -1  0  0 |     |           |      |  -pi   |
+        |            |     |  theta_x  |      |        |
+        | 0 -1  1  0 |  .  |           |  >=  |   0    |
+        |            |     |  theta_y  |      |        |
+        | 0  0  1  0 |     |           |      |   0    |
+        |            |     | sigma_max |      |        |
+        | 0  0 -1  0 |                        |  -pi   |
+        |            |                        |        |
+        | 0  0  0  1 |                        |   0    |
+        |            |                        |        |
+        | 0  0  0 -1 |                        |  -pi   |
+
+    The pivot and average position constraints in the A.x >= b notation are::
+
+        | 1  0  0  0  0  0 |                        | -999.0 |
+        |                  |                        |        |
+        |-1  0  0  0  0  0 |                        | -999.0 |
+        |                  |                        |        |
+        | 0  1  0  0  0  0 |                        | -999.0 |
+        |                  |                        |        |
+        | 0 -1  0  0  0  0 |     |  pivot_x  |      | -999.0 |
+        |                  |     |           |      |        |
+        | 0  0  1  0  0  0 |     |  pivot_y  |      | -999.0 |
+        |                  |     |           |      |        |
+        | 0  0 -1  0  0  0 |     |  pivot_z  |      | -999.0 |
+        |                  |  .  |           |  >=  |        |
+        | 0  0  0  1  0  0 |     | ave_pos_x |      | -500.0 |
+        |                  |     |           |      |        |
+        | 0  0  0 -1  0  0 |     | ave_pos_y |      | -500.0 |
+        |                  |     |           |      |        |
+        | 0  0  0  0  1  0 |     | ave_pos_z |      | -500.0 |
+        |                  |                        |        |
+        | 0  0  0  0 -1  0 |                        | -500.0 |
+        |                  |                        |        |
+        | 0  0  0  0  0  1 |                        | -500.0 |
+        |                  |                        |        |
+        | 0  0  0  0  0 -1 |                        | -500.0 |
 
 
     @keyword scaling_matrix:    The diagonal, square scaling matrix.
@@ -122,6 +169,28 @@ def linear_constraints(scaling_matrix=None):
 
     # Loop over the parameters of the model.
     for i in range(n):
+        # The pivot parameters.
+        if cdp.params[i] in ['pivot_x', 'pivot_y', 'pivot_z']:
+            # -999 <= pivot_i <= 999.
+            A.append(zero_array * 0.0)
+            A.append(zero_array * 0.0)
+            A[j][i] = 1.0
+            A[j+1][i] = -1.0
+            b.append(-999.0 / scaling_matrix[i, i])
+            b.append(-999.0 / scaling_matrix[i, i])
+            j = j + 2
+
+        # The average domain translation parameters.
+        if cdp.params[i] in ['ave_pos_x', 'ave_pos_y', 'ave_pos_z']:
+            # -500 <= ave_pos_i <= 500.
+            A.append(zero_array * 0.0)
+            A.append(zero_array * 0.0)
+            A[j][i] = 1.0
+            A[j+1][i] = -1.0
+            b.append(-500.0 / scaling_matrix[i, i])
+            b.append(-500.0 / scaling_matrix[i, i])
+            j = j + 2
+
         # The cone opening angles and sigma_max.
         if cdp.params[i] in ['cone_theta', 'cone_theta_x', 'cone_theta_y', 'cone_sigma_max']:
             # 0 <= theta <= pi.
@@ -144,21 +213,15 @@ def linear_constraints(scaling_matrix=None):
                         j = j + 1
 
 
-        # The order parameter.
-        if cdp.params[i] == 'cone_s1':
-            # -0.125 <= S <= 1.
-            A.append(zero_array * 0.0)
-            A.append(zero_array * 0.0)
-            A[j][i] = 1.0
-            A[j+1][i] = -1.0
-            b.append(-0.125 / scaling_matrix[i, i])
-            b.append(-1 / scaling_matrix[i, i])
-            j = j + 2
-
     # Convert to numpy data structures.
     A = array(A, float64)
     b = array(b, float64)
 
+    # No constraints are present.
+    if len(A) == 0:
+        A = None
+        b = None
+
     # Return the constraint objects.
     return A, b
 
@@ -171,82 +234,86 @@ def param_num():
     """
 
     # Update the model, just in case.
-    update_model()
+    update_model(verbosity=0)
 
     # Simple parameter list count.
     return len(cdp.params)
 
 
-def update_model():
-    """Update the model parameters as necessary."""
+def update_model(verbosity=1):
+    """Update the model parameters as necessary.
+
+    @keyword verbosity: If this value is greater than zero, then a number of printouts will occur.
+    @type verbosity:    int
+    """
 
     # Re-initialise the list of model parameters.
     cdp.params = []
+    updated = []
 
     # The pivot parameters.
     if not pivot_fixed():
+        updated.append("pivot parameters")
         cdp.params.append('pivot_x')
         cdp.params.append('pivot_y')
         cdp.params.append('pivot_z')
 
-        # Double rotor.
-        if cdp.model == 'double rotor':
-            cdp.params.append('pivot_x_2')
-            cdp.params.append('pivot_y_2')
-            cdp.params.append('pivot_z_2')
+    # The 2nd pivot point parameters - the minimum inter rotor axis distance.
+    if cdp.model in [MODEL_DOUBLE_ROTOR]:
+        updated.append("pivot parameters")
+        cdp.params.append('pivot_disp')
 
     # The average domain position translation parameters.
-    if not translation_fixed():
-        cdp.params.append('ave_pos_x')
-        cdp.params.append('ave_pos_y')
-        cdp.params.append('ave_pos_z')
+    updated.append("average domain position")
+    cdp.params.append('ave_pos_x')
+    cdp.params.append('ave_pos_y')
+    cdp.params.append('ave_pos_z')
 
     # The tensor rotation, or average domain position.
-    if cdp.model not in ['free rotor', 'iso cone, free rotor']:
+    if cdp.model not in MODEL_LIST_FREE_ROTORS:
         cdp.params.append('ave_pos_alpha')
     cdp.params.append('ave_pos_beta')
     cdp.params.append('ave_pos_gamma')
 
     # Frame order eigenframe - the full frame.
-    if cdp.model in ['pseudo-ellipse', 'pseudo-ellipse, torsionless', 'pseudo-ellipse, free rotor']:
+    if cdp.model in MODEL_LIST_PSEUDO_ELLIPSE + [MODEL_DOUBLE_ROTOR]:
+        updated.append("frame order eigenframe")
         cdp.params.append('eigen_alpha')
         cdp.params.append('eigen_beta')
         cdp.params.append('eigen_gamma')
 
     # Frame order eigenframe - the isotropic cone axis.
-    if cdp.model in ['iso cone', 'free rotor', 'iso cone, torsionless', 'iso cone, free rotor', 'double rotor']:
+    if cdp.model in MODEL_LIST_ISO_CONE:
+        updated.append("frame order eigenframe")
         cdp.params.append('axis_theta')
         cdp.params.append('axis_phi')
 
-    # Frame order eigenframe - the second rotation axis.
-    if cdp.model in ['double rotor']:
-        cdp.params.append('axis_theta_2')
-        cdp.params.append('axis_phi_2')
-
     # Frame order eigenframe - the rotor axis alpha angle.
-    if cdp.model in ['rotor']:
+    if cdp.model in [MODEL_ROTOR, MODEL_FREE_ROTOR]:
+        updated.append("frame order eigenframe")
         cdp.params.append('axis_alpha')
 
     # Cone parameters - pseudo-elliptic cone parameters.
-    if cdp.model in ['pseudo-ellipse', 'pseudo-ellipse, torsionless', 'pseudo-ellipse, free rotor']:
+    if cdp.model in MODEL_LIST_PSEUDO_ELLIPSE:
+        updated.append("cone opening half-angles")
         cdp.params.append('cone_theta_x')
         cdp.params.append('cone_theta_y')
 
     # Cone parameters - single isotropic angle or order parameter.
-    if cdp.model in ['iso cone', 'iso cone, torsionless']:
+    if cdp.model in [MODEL_ISO_CONE, MODEL_ISO_CONE_FREE_ROTOR, MODEL_ISO_CONE_TORSIONLESS]:
+        updated.append("cone opening half-angles")
         cdp.params.append('cone_theta')
-    if cdp.model in ['iso cone, free rotor']:
-        cdp.params.append('cone_s1')
 
     # Cone parameters - torsion angle.
-    if cdp.model in ['double rotor', 'rotor', 'line', 'iso cone', 'pseudo-ellipse']:
+    if cdp.model in [MODEL_DOUBLE_ROTOR, MODEL_ROTOR, MODEL_ISO_CONE, MODEL_PSEUDO_ELLIPSE]:
+        updated.append("cone torsion half-angles")
         cdp.params.append('cone_sigma_max')
 
     # Cone parameters - 2nd torsion angle.
-    if cdp.model in ['double rotor']:
+    if cdp.model in [MODEL_DOUBLE_ROTOR]:
+        updated.append("cone torsion half-angles")
         cdp.params.append('cone_sigma_max_2')
 
-    # Initialise the parameters in the current data pipe.
-    for param in cdp.params:
-        if not param in ['pivot_x', 'pivot_y', 'pivot_z', 'pivot_x_2', 'pivot_y_2', 'pivot_z_2'] and not hasattr(cdp, param):
-            setattr(cdp, param, 0.0)
+    # Printout.
+    if verbosity:
+        print("Reinitialising the list of model parameters:  %s" % unique_elements(updated))
