@@ -89,7 +89,7 @@ def iinf_upper(incs=None, model_info=None):
 
     # Find the ID of the last time point.
     max_time = max(cdp.relax_times.values())
-    for key in list(cdp.relax_times.keys()):
+    for key in cdp.relax_times:
         if cdp.relax_times[key] == max_time:
             id = key
             break
@@ -120,6 +120,9 @@ class Relax_fit_params(Param_list):
         # Add the base data.
         self._add_peak_intensity()
 
+        # Add the signal to noise ratio.
+        self._add_sn_ratio()
+
         # Add the base information for the analysis.
         self._add(
             'relax_times',
