@@ -1,9 +1,19 @@
-# Script for optimising the second free rotor frame order test model of CaM.
+# Script for optimising the second free rotor isotropic cone frame order test model of CaM.
 
 # Python module imports.
 from numpy import array
 
 
+# The real parameter values.
+AVE_POS_X = -13.9092836985788
+AVE_POS_Y = -0.36893728819422167
+AVE_POS_Z = 2.8352640418129806
+AVE_POS_BETA = 5.389498937346155
+AVE_POS_GAMMA = 0.09243393677259322
+AXIS_THETA = 0.69828059079619353433
+AXIS_PHI = 4.03227550621962294031
+CONE_THETA = 1.1
+
 # Create the data pipe.
 pipe.create(pipe_name='frame order', pipe_type='frame order')
 
@@ -39,8 +49,8 @@ for i in range(len(ln)):
 script('../tensors.py')
 
 # Define the domains.
-domain(id='N', spin_id=":1-78")
-domain(id='C', spin_id=":80-148")
+domain(id='N', spin_id="#N-dom")
+domain(id='C', spin_id="#C-dom")
 
 # The tensor domains and reductions.
 full = ['Dy N-dom', 'Tb N-dom', 'Tm N-dom', 'Er N-dom']
@@ -60,9 +70,6 @@ for i in range(len(full)):
 # Select the model.
 frame_order.select_model('iso cone, free rotor')
 
-# Set up the mechanics of the displacement to the average domain position.
-frame_order.average_position(pivot='motional', translation=False)
-
 # Set the reference domain.
 frame_order.ref_domain('N')
 
@@ -73,38 +80,66 @@ frame_order.pivot(pivot, fix=True)
 # Set the paramagnetic centre.
 paramag.centre(pos=[35.934, 12.194, -4.206])
 
-# The optimisation settings.
-frame_order.num_int_pts(num=50)
+# Check the minimum (at a very high quality to check that the chi-squared value is zero).
+frame_order.num_int_pts(num=100000)
+value.set(param='ave_pos_x', val=AVE_POS_X)
+value.set(param='ave_pos_y', val=AVE_POS_Y)
+value.set(param='ave_pos_z', val=AVE_POS_Z)
+value.set(param='ave_pos_beta', val=AVE_POS_BETA)
+value.set(param='ave_pos_gamma', val=AVE_POS_GAMMA)
+value.set(param='axis_theta', val=AXIS_THETA)
+value.set(param='axis_phi', val=AXIS_PHI)
+value.set(param='cone_theta', val=CONE_THETA)
+minimise.calculate()
 frame_order.quad_int(flag=False)
 
-# Check the minimum.
-value.set(param='ave_pos_beta', val=0.77485244603476433)
-value.set(param='ave_pos_gamma', val=0.1420704587263735)
-value.set(param='axis_theta', val=0.69828059079619353433)
-value.set(param='axis_phi', val=4.03227550621962294031)
-value.set(param='cone_s1', val=iso_cone_theta_to_S(1.2))
-minimise.calculate()
-print("\nchi2: %s" % repr(cdp.chi2))
+# Create the PDB representation of the true state.
+frame_order.pdb_model(ave_pos='ave_pos_true', rep='frame_order_true', dist=None, compress_type=2, force=True)
 
-# Optimise.
-#minimise.grid_search(inc=5)
-minimise.execute('simplex', constraints=False)
+# Save the state.
+state.save('frame_order_true', force=True)
+
+# Grid search (low quality for speed).
+frame_order.num_int_pts(num=200)
+minimise.grid_search(inc=[None, None, None, None, None, 11, 11, 11])
+
+# Iterative optimisation with increasing precision.
+num_int_pts = [1000, 10000, 50000]
+func_tol = [1e-2, 1e-3, 1e-4]
+for i in range(len(num_int_pts)):
+    frame_order.num_int_pts(num=num_int_pts[i])
+    minimise.execute('simplex', func_tol=func_tol[i])
+
+# Store the result.
+frame_order.pdb_model(ave_pos='ave_pos_fixed_piv', rep='frame_order_fixed_piv', dist=None, compress_type=2, force=True)
+
+# Save the state.
+state.save('frame_order_fixed_piv', force=True)
+
+# Optimise the pivot and model, again iterating with increasing precision.
+frame_order.pivot(pivot, fix=False)
+num_int_pts = [1000, 10000, 50000]
+func_tol = [1e-2, 1e-3, 1e-4]
+for i in range(len(num_int_pts)):
+    frame_order.num_int_pts(num=num_int_pts[i])
+    minimise.execute('simplex', func_tol=func_tol[i])
 
 # Test Monte Carlo simulations.
+frame_order.num_int_pts(num=10000)
 monte_carlo.setup(number=5)
 monte_carlo.create_data()
 monte_carlo.initial_values()
-minimise.execute('simplex', constraints=False)
+minimise.execute('simplex', func_tol=1e-2)
 eliminate()
 monte_carlo.error_analysis()
 
 # Create the PDB representation.
-frame_order.pdb_model(force=True)
+frame_order.pdb_model(ave_pos='ave_pos', rep='frame_order', dist=None, compress_type=2, force=True)
 
 # PyMOL.
-pymol.view()
-pymol.command('show spheres')
-pymol.cone_pdb('frame_order.pdb')
+pymol.frame_order(ave_pos='ave_pos_true', rep='frame_order_true', dist=None)
+pymol.frame_order(ave_pos='ave_pos_fixed_piv', rep='frame_order_fixed_piv', dist=None)
+pymol.frame_order(ave_pos='ave_pos', rep='frame_order', dist=None)
 
 # Save the state.
 state.save('frame_order', force=True)
