@@ -39,8 +39,8 @@ for i in range(len(ln)):
 script('../../tensors.py')
 
 # Define the domains.
-domain(id='N', spin_id=":1-78")
-domain(id='C', spin_id=":80-148")
+domain(id='N', spin_id="#N-dom")
+domain(id='C', spin_id="#C-dom")
 
 # The tensor domains and reductions.
 full = ['Dy N-dom', 'Tb N-dom', 'Tm N-dom', 'Er N-dom']
@@ -60,9 +60,6 @@ for i in range(len(full)):
 # Select the model.
 frame_order.select_model('rotor')
 
-# Set up the mechanics of the displacement to the average domain position.
-frame_order.average_position(pivot='motional', translation=False)
-
 # Set the reference domain.
 frame_order.ref_domain('N')
 
@@ -104,8 +101,6 @@ minimise.execute('simplex', constraints=False)
 frame_order.pdb_model(force=True)
 
 # PyMOL.
-pymol.view()
-pymol.command('show spheres')
 pymol.cone_pdb('frame_order.pdb')
 
 # Save the state.
