@@ -115,9 +115,6 @@ frame_order.ref_domain('fixed')
 # Link the domains to the PDB files.
 frame_order.domain_to_pdb(domain='fixed', pdb='displaced.pdb')
 
-# Set up the mechanics of the displacement to the average domain position.
-frame_order.average_position(pivot='com', translation=True)
-
 # Set the initial pivot point (should make no difference for the rigid model).
 pivot = array([0, 0, 0], float64)
 frame_order.pivot(pivot, fix=True)
@@ -137,7 +134,6 @@ cdp.ave_pos_beta  = 2.0
 cdp.ave_pos_gamma = 2.14159265359
 
 # Set some parameters close to zero, but far enough away from zero to allow for the numerical integration.
-cdp.cone_s1 = 0.99
 cdp.cone_theta = 0.1
 cdp.cone_theta_x = 0.1
 cdp.cone_theta_y = 0.1
