@@ -121,9 +121,6 @@ for i in range(len(full)):
 # Set the reference domain.
 self._execute_uf(uf_name='frame_order.ref_domain', ref='fixed')
 
-# Set up the mechanics of the displacement to the average domain position.
-self._execute_uf(uf_name='frame_order.average_position', pivot='com', translation=True)
-
 # Set the initial pivot point (should make no difference for the rigid model).
 pivot = array([0, 0, 0], float64)
 self._execute_uf(uf_name='frame_order.pivot', pivot=pivot, fix=True)
@@ -132,7 +129,7 @@ self._execute_uf(uf_name='frame_order.pivot', pivot=pivot, fix=True)
 self._execute_uf(uf_name='paramag.centre', pos=[-5, -7, -9])
 
 # Set the number of integration points.
-self._execute_uf(uf_name='frame_order.num_int_pts', num=10000)
+self._execute_uf(uf_name='frame_order.sobol_setup', max_num=100)
 
 # Set the real parameter values (the inverted displacement values).
 cdp.ave_pos_x = -1
@@ -142,12 +139,23 @@ cdp.ave_pos_alpha = 0.14159265359
 cdp.ave_pos_beta  = 2.0
 cdp.ave_pos_gamma = 2.14159265359
 
-# Set some parameters close to zero, but far enough away from zero to allow for the numerical integration.
-cdp.cone_s1 = 0.99
-cdp.cone_theta = 0.05
-cdp.cone_theta_x = 0.1
-cdp.cone_theta_y = 0.1
-cdp.cone_sigma_max = 0.05
+# Set the pivot parameter.
+cdp.pivot_disp = 100.0
+
+# Set the eigenframe parameters to allow the minimise.calculate user function to operate.
+cdp.axis_alpha = 1.0
+cdp.axis_theta = 1.0
+cdp.axis_phi = 1.0
+cdp.eigen_alpha = 1.0
+cdp.eigen_beta = 1.0
+cdp.eigen_gamma = 1.0
+
+# Set the order parameters to insignificant values.
+cdp.cone_theta = 0.0
+cdp.cone_theta_x = 0.0
+cdp.cone_theta_y = 0.0
+cdp.cone_sigma_max = 0.0
+cdp.cone_sigma_max_2 = 0.0
 
 # Allow for stand-alone operation.
 if not hasattr(ds, 'model'):
