@@ -31,5 +31,5 @@ sequence.display()
 monte_carlo.setup(number=5)
 monte_carlo.create_data(method='back_calc')
 monte_carlo.initial_values()
-minimise()
+minimise.execute()
 monte_carlo.error_analysis()
