@@ -174,6 +174,28 @@ uf.wizard_image = WIZARD_IMAGE_PATH + 'spectrum' + sep + 'spectrum_200.png'
 uf.wizard_apply_button = False
 
 
+# The spectrum.error_analysis_per_field user function.
+uf = uf_info.add_uf('spectrum.error_analysis_per_field')
+uf.title = "Use spectrum IDs per each field strength for an error analysis for peak intensities."
+uf.title_short = "Per field strength peak intensity error analysis."
+# Description.
+uf.desc.append(Desc_container())
+uf.desc[-1].add_paragraph("Please see the spectrum.error_analysis user function documentation.")
+uf.desc[-1].add_paragraph("This user function will collect all spectrum IDs for each field strength separately, and call the spectrum.error_analysis with these.")
+uf.desc[-1].add_paragraph("This function is meant as a short-cut for the spectrum.error_analysis function.")
+# Prompt examples.
+uf.desc.append(Desc_container("Prompt examples"))
+uf.desc[-1].add_paragraph("To collect all spectrum IDs per field strength, and perform peak intensity error analysis:")
+uf.desc[-1].add_prompt("relax> spectrum.error_analysis_per_field()")
+uf.backend = spectrum.error_analysis_per_field
+uf.menu_text = "&error_analysis_per_field"
+uf.gui_icon = "oxygen.categories.applications-education"
+uf.wizard_height_desc = 530
+uf.wizard_size = (1000, 700)
+uf.wizard_image = WIZARD_IMAGE_PATH + 'spectrum' + sep + 'spectrum_200.png'
+uf.wizard_apply_button = False
+
+
 # The spectrum.integration_points user function.
 uf = uf_info.add_uf('spectrum.integration_points')
 uf.title = "Set the number of summed points used in volume integration of a given spin in a spectrum."
@@ -516,3 +538,22 @@ uf.menu_text = "re&plicated"
 uf.gui_icon = "oxygen.actions.edit-rename"
 uf.wizard_size = (700, 500)
 uf.wizard_image = WIZARD_IMAGE_PATH + 'spectrum' + sep + 'spectrum_200.png'
+
+
+# The spectrum.sn_ratio user function.
+uf = uf_info.add_uf('spectrum.sn_ratio')
+uf.title = "Calculate the signal to noise ratio for all selected spins."
+uf.title_short = "Signal to noise calculation."
+# Description.
+uf.desc.append(Desc_container())
+uf.desc[-1].add_paragraph("This user function will per spin calculate the signal to noise ratio: S/N.")
+# Prompt examples.
+uf.desc.append(Desc_container("Prompt examples"))
+uf.desc[-1].add_paragraph("To calculate the Signal to Noise ratio per spin.")
+uf.desc[-1].add_prompt("relax> spectrum.sn_ratio()")
+uf.backend = spectrum.signal_noise_ratio
+uf.menu_text = "&sn_ratio"
+uf.gui_icon = "relax.fid"
+uf.wizard_size = (600, 400)
+uf.wizard_image = WIZARD_IMAGE_PATH + 'spectrum' + sep + 'spectrum_200.png'
+uf.wizard_apply_button = False
